@@ -1,10 +1,16 @@
 #!/bin/sh
 # Run this to generate all the initial makefiles, etc.
-
+set -e
 echo "Running mkdir -p config"
 mkdir -p config
-echo "Running libtoolize --force"
-libtoolize --force
+if command -v glibtoolize
+then
+	LIBTOOLIZE=glibtoolize
+else
+	LIBTOOLIZE=libtoolize
+fi
+echo "Running ${LIBTOOLIZE} --force"
+${LIBTOOLIZE} --force
 echo "Running aclocal"
 aclocal -I ./m4
 echo "Running autoheader"
