@@ -46,7 +46,7 @@ const char * libofx_get_file_format_description(const struct LibofxFileFormatInf
     }
   }
   return retval;
-};
+}
 
 /*
 libofx_get_file_type returns a proper enum from a file type string.
@@ -78,7 +78,7 @@ int libofx_proc_file(LibofxContextPtr p_libofx_context, const char * p_filename,
   }
   else
   {
-    libofx_context->setCurrentFileType(libofx_detect_file_type(p_filename));
+    libofx_context->setCurrentFileType(p_file_type);
     message_out(INFO,
                 string("libofx_proc_file(): File format forced to: ") +
                 libofx_get_file_format_description(LibofxImportFormatList,
@@ -88,15 +88,14 @@ int libofx_proc_file(LibofxContextPtr p_libofx_context, const char * p_filename,
   switch (libofx_context->currentFileType())
   {
   case OFX:
-    ofx_proc_file(libofx_context, p_filename);
-    break;
+    return ofx_proc_file(libofx_context, p_filename);
   case OFC:
-    ofx_proc_file(libofx_context, p_filename);
-    break;
+    return ofx_proc_file(libofx_context, p_filename);
   default:
-    message_out(ERROR, string("libofx_proc_file(): Detected file format not yet supported ou couldn't detect file format; aborting."));
+    message_out(ERROR, string("libofx_proc_file(): Could not detect file format, or unsupported file format; aborting."));
+    return -1;
   }
-  return 0;
+  return 0; // never reached
 }
 
 enum LibofxFileFormat libofx_detect_file_type(const char * p_filename)
@@ -126,7 +125,7 @@ enum LibofxFileFormat libofx_detect_file_type(const char * p_filename)
         //cout<<buffer<<"\n";
         s_buffer.assign(buffer);
         //cout<<"input_file.gcount(): "<<input_file.gcount()<<" sizeof(buffer): "<<sizeof(buffer)<<endl;
-        if (input_file.gcount() < (sizeof(buffer) - 1))
+        if (input_file.gcount() < int(sizeof(buffer) - 1))
         {
           s_buffer.append("\n");//Just in case...
         }
