@@ -62,7 +62,8 @@ OfxPushUpContainer::OfxPushUpContainer(LibofxContext *p_libofx_context, OfxGener
 void OfxPushUpContainer::add_attribute(const string identifier, const string value)
 {
   //message_out(DEBUG, "OfxPushUpContainer for "+tag_identifier+" will push up a "+identifier+" ("+value+") to a "+ parentcontainer->type + " container");
-  parentcontainer->add_attribute(identifier, value);
+  if (parentcontainer)
+    parentcontainer->add_attribute(identifier, value);
 }
 
 /***************************************************************************
@@ -76,8 +77,7 @@ OfxStatusContainer::OfxStatusContainer(LibofxContext *p_libofx_context, OfxGener
   type = "STATUS";
   if (parentcontainer != NULL)
   {
-    strncpy(data.ofx_element_name, parentcontainer->tag_identifier.c_str(), OFX_ELEMENT_NAME_LENGTH);
-    data.ofx_element_name_valid = true;
+    ASSIGN_STRNCPY(data.ofx_element_name, parentcontainer->tag_identifier);
   }
 
 }
@@ -97,11 +97,10 @@ void OfxStatusContainer::add_attribute(const string identifier, const string val
 
   if ( identifier == "CODE")
   {
-    data.code = atoi(value.c_str());
+    ASSIGN(data.code, atoi(value.c_str()));
     error_msg = find_error_msg(data.code);
     data.name = error_msg.name;//memory is already allocated
     data.description = error_msg.description;//memory is already allocated
-    data.code_valid = true;
   }
   else if (identifier == "SEVERITY")
   {
@@ -126,7 +125,7 @@ void OfxStatusContainer::add_attribute(const string identifier, const string val
   }
   else if ((identifier == "MESSAGE") || (identifier == "MESSAGE2"))
   {
-    data.server_message = new char[value.length()+1];
+    data.server_message = new char[value.length() + 1];
     strcpy(data.server_message, value.c_str());
     data.server_message_valid = true;
   }
@@ -148,6 +147,9 @@ OfxBalanceContainer::OfxBalanceContainer(LibofxContext *p_libofx_context, OfxGen
 {
   amount_valid = false;
   date_valid = false;
+  margin_balance_valid = false;
+  short_balance_valid = false;
+  buying_power_valid = false;
   type = "BALANCE";
 }
 
@@ -159,20 +161,32 @@ OfxBalanceContainer::~OfxBalanceContainer()
   }
   else
   {
-    message_out (ERROR, "I completed a " + type + " element, but I havent found a suitable parent to save it");
+    message_out (ERROR, "I completed a " + type + " element, but I haven't found a suitable parent to save it");
   }
 }
 void OfxBalanceContainer::add_attribute(const string identifier, const string value)
 {
-  if (identifier == "BALAMT")
+  if (identifier == "BALAMT" ||
+      identifier == "AVAILCASH" ||  // from <INVBAL>
+      identifier == "CASHBAL")      // from <INV401KBAL>
   {
-    amount = ofxamount_to_double(value);
-    amount_valid = true;
+    ASSIGN(amount, ofxamount_to_double(value));
+  }
+  else if (identifier == "MARGINBALANCE")
+  {
+    ASSIGN(margin_balance, ofxamount_to_double(value));
+  }
+  else if (identifier == "SHORTBALANCE")
+  {
+    ASSIGN(short_balance, ofxamount_to_double(value));
+  }
+  else if (identifier == "BUYPOWER")
+  {
+    ASSIGN(buying_power, ofxamount_to_double(value));
   }
   else if (identifier == "DTASOF")
   {
-    date = ofxdate_to_time_t(value);
-    date_valid = true;
+    ASSIGN(date, ofxdate_to_time_t(value));
   }
   else
   {
@@ -180,3 +194,30 @@ void OfxBalanceContainer::add_attribute(const string identifier, const string va
     OfxGenericContainer::add_attribute(identifier, value);
   }
 }
+
+/***************************************************************************
+ *                         OfxInv401kContainer                             *
+ * This container is only used to throw away the multiple possible         *
+ * <DTSTART>, <DTASOF> and <DTEND> elements that can occur under <INV401K> *
+ * so they don't corrupt the statement dates.                              *
+***************************************************************************/
+
+OfxInv401kContainer::OfxInv401kContainer(LibofxContext *p_libofx_context, OfxGenericContainer *para_parentcontainer, string para_tag_identifier):
+  OfxGenericContainer(p_libofx_context, para_parentcontainer, para_tag_identifier)
+{
+  type = "INV401K";
+  message_out(INFO, "Created OfxInv401kContainer to hold unsupported aggregate " + para_tag_identifier);
+}
+void OfxInv401kContainer::add_attribute(const string identifier, const string value)
+{
+  if (identifier == "DTSTART" || identifier == "DTEND" || identifier == "DTASOF")
+  {
+    message_out(DEBUG, "OfxInv401kContainer for " + tag_identifier + " ignored a " + identifier + " (" + value + ")");
+  }
+  else
+  {
+    /* Redirect unknown identifiers to the base class */
+    OfxGenericContainer::add_attribute(identifier, value);
+  }
+}
+
